@@ -121,12 +121,12 @@ class CW(AbstractStartComp):
             If True, the last wave to enter/exit a port will be saved.
         pre_call_code :
             A string containing code which will be executed prior to
-            the call to the function :func:`__call__`. The two parameters
-            `input_ports` and `input_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `input_ports` and `input_fields` are available.
         post_call_code :
             A string containing code which will be executed posterior to
-            the call to the function :func:`__call__`. The two parameters
-            `output_ports` and `output_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `output_ports` and `output_fields` are available.
 
         """
         # Parent constructor -------------------------------------------
@@ -242,4 +242,4 @@ if __name__ == "__main__":
 
     oc.plot2d(x_datas, y_datas, x_labels=["t","nu","t","nu"],
               y_labels=["P_t", "P_nu", "phi_t", "phi_nu"],
-              plot_titles=plot_titles, split=True, opacity=[0.2])
+              plot_titles=plot_titles, split=True, line_opacities=[0.2])
