@@ -97,7 +97,7 @@ class Gaussian(AbstractStartComp):
               \bigg(\frac{t-t_0}{T_0}\bigg)^{2m}
               + i\big(\phi_0 - 2\pi (\nu_c  + \nu_{offset})t\big)\bigg]
 
-    where :math:`t_0` is the half width at :math:`1/e`-intensity.
+    where :math:`T_0` is the half width at :math:`1/e`-intensity.
 
     Component diagram::
 
@@ -158,12 +158,12 @@ class Gaussian(AbstractStartComp):
             If True, the last wave to enter/exit a port will be saved.
         pre_call_code :
             A string containing code which will be executed prior to
-            the call to the function :func:`__call__`. The two parameters
-            `input_ports` and `input_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `input_ports` and `input_fields` are available.
         post_call_code :
             A string containing code which will be executed posterior to
-            the call to the function :func:`__call__`. The two parameters
-            `output_ports` and `output_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `output_ports` and `output_fields` are available.
 
         """
         # Parent constructor -------------------------------------------
