@@ -26,6 +26,8 @@ from optcom.field import Field
 from optcom.utils.fft import FFT
 
 
+from optcom.components.gaussian import Gaussian
+
 default_name = 'Gaussian Filter'
 
 
@@ -86,7 +88,8 @@ class GaussianFilter(AbstractPassComp):
         name :
             The name of the component.
         nu_bw :
-            The frequency spectral bandwidth. :math:`[ps^{-1}]`
+            The spectral bandwidth. :math:`[ps^{-1}]`  Correspond to
+            the FWHM of the Gaussian window.
         nu_offset :
             The offset frequency. :math:`[ps^{-1}]`
         order :
@@ -119,11 +122,33 @@ class GaussianFilter(AbstractPassComp):
         util.check_attr_type(order, 'order', int)
         # Attr ---------------------------------------------------------
         self.nu_bw = nu_bw
+        self.nu_bw =  Gaussian.fwhm_to_width(nu_bw, order)
         self.nu_offset = nu_offset
         self.order = order
         # Policy -------------------------------------------------------
         self.add_port_policy(([0],[1],True))
     # ==================================================================
+    @staticmethod
+    def transfer_function(nu: np.ndarray, center_nu: float, nu_bw: float,
+                          offset_nu: float = .0, order: int = 1):
+        """The transfer function of the flat top window.
+
+        Parameters
+        ----------
+        nu :
+            The frequency components.
+        center_nu :
+            The center frequency.
+
+        """
+        nu_bw = Gaussian.fwhm_to_width(nu_bw, order)
+        delta_nu = nu - offset_nu - center_nu
+        window = np.zeros(delta_nu.shape, dtype=complex)
+        arg = np.power(delta_nu/nu_bw, 2*order)
+        window = np.exp(-0.5*arg)
+
+        return Field.temporal_power(window)
+    # ==================================================================
     @call_decorator
     def __call__(self, domain: Domain, ports: List[int], fields: List[Field]
                  ) -> Tuple[List[int], List[Field]]:
@@ -133,9 +158,10 @@ class GaussianFilter(AbstractPassComp):
         for field in fields:
             nu = domain.nu - self.nu_offset
             for i in range(len(field)):
-                arg = np.zeros(nu.shape, dtype=complex)
+                window = np.zeros(nu.shape, dtype=complex)
                 arg = FFT.ifftshift(np.power(nu/self.nu_bw, 2*self.order))
-                field[i] = FFT.ifft(np.exp(-0.5*arg) * FFT.fft(field[i]))
+                window = np.exp(-0.5*arg)
+                field[i] = FFT.ifft(window * FFT.fft(field[i]))
             output_fields.append(field)
 
         return self.output_ports(ports), output_fields
@@ -153,17 +179,36 @@ if __name__ == "__main__":
 
     import optcom as oc
 
-    lt: oc.Layout = oc.Layout(oc.Domain(bit_width=600.))
+    # Plot transfer function
+    domain = Domain(samples_per_bit = 2**12)
+    center_lambda = 1030.
+    center_nu = oc.lambda_to_nu(center_lambda)
+    nu = domain.nu + center_nu
+    lambda_bw = 2.
+    nu_bw = oc.lambda_bw_to_nu_bw(lambda_bw, center_lambda)
+    tf = oc.GaussianFilter.transfer_function(nu, center_nu, nu_bw, 0.0)#1.5)
+    lambdas = oc.nu_to_lambda(nu)
+    oc.plot2d(lambdas, tf, x_labels=['nu'], y_labels=['Amplitude (a.u.)'],
+              plot_titles=["Transfer function centered at "
+                           "{} nm with bandwidth {} nm"
+                           .format(round(center_lambda, 2), round(lambda_bw))])
+    # Apply on pulse and plot
+    bit_width = 1000.
+    lt: oc.Layout = oc.Layout(oc.Domain(samples_per_bit=2**13,
+                                        bit_width=bit_width))
 
-    nu_bw: float = 0.01
+    lambda_bw = 0.05 # nm
+    nu_bw = oc.lambda_bw_to_nu_bw(lambda_bw, center_lambda)
     pulse: oc.Gaussian = oc.Gaussian(channels=2, peak_power=[10.0, 19.0],
-                                     width=[10., 6.])
+                                     width=[10., 6.],
+                                     center_lambda=[center_lambda])
     filter: oc.GaussianFilter = oc.GaussianFilter(nu_bw=nu_bw, nu_offset=0.,
                                                   order=1)
     lt.add_link(pulse[0], filter[0])
     lt.run(pulse)
     plot_titles: List[str] = ["Original pulse", r"After Gaussian filter with "
-                              "frequency bandwidth {} THz.".format(nu_bw)]
+                              "frequency bandwidth {} THz."
+                              .format(round(nu_bw, 2))]
     plot_titles += plot_titles
     y_datas: List[np.ndarray] = [oc.temporal_power(pulse[0][0].channels),
                                  oc.temporal_power(filter[1][0].channels),
@@ -173,6 +218,10 @@ if __name__ == "__main__":
                                  pulse[0][0].nu, filter[1][0].nu]
     x_labels: List[str] = ['t', 't', 'nu', 'nu']
     y_labels: List[str] = ['P_t', 'P_t', 'P_nu', 'P_nu']
+    nu_range = (center_nu-.1, center_nu+.1)
+    time_range = (bit_width/2.+75., bit_width/2.-75.)
+    x_ranges = [time_range, time_range, nu_range, nu_range]
 
     oc.plot2d(x_datas, y_datas, plot_titles=plot_titles, x_labels=x_labels,
-              y_labels=y_labels, split=True, line_opacities=[0.3])
+              y_labels=y_labels, split=True, line_opacities=[0.3],
+              x_ranges=x_ranges)
