@@ -1,17 +1,16 @@
-# This file is part of Optcom.
+# Copyright 2019 The Optcom Authors
 #
-# Optcom is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# Optcom is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with Optcom.  If not, see <https://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 """.. moduleauthor:: Sacha Medaer"""
 
@@ -394,8 +393,10 @@ class Field(object):
         res: Field = getattr(self, operator)(field_operand)
         for i in range(len(field_operand[:])):
             if (i not in map):
-                res.append(field_operand[i], field_operand.center_omega[i],
-                           field_operand.rep_freq[i], field_operand.delays[i])
+                res.add_channel(field_operand[i],
+                                field_operand.center_omega[i],
+                                field_operand.rep_freq[i],
+                                field_operand.delays[i])
 
         return res
     # ==================================================================
@@ -502,8 +503,8 @@ class Field(object):
         """
         if (self.has_equal_charact(field)):
             for j in range(len(field)):
-                self.append(field[j], field.center_omega[j], field.rep_freq[j],
-                            field.delays[j])
+                self.add_channel(field[j], field.center_omega[j],
+                                 field.rep_freq[j], field.delays[j])
             self._noise += field.noise
         else:
             warning_message: str = ("Two fields must have same number of "
@@ -511,9 +512,9 @@ class Field(object):
                 "Operation aborted.")
             warnings.warn(warning_message, CompatibilityWarning)
     # ==================================================================
-    def append(self, channel: np.ndarray, center_omega: float,
-               rep_freq: float, delay: float = 0.0):
-        """Append a channel to the field.  The channel must comply with
+    def add_channel(self, channel: np.ndarray, center_omega: float,
+                    rep_freq: float, delay: float = 0.0):
+        """Aadd a channel to the field.  The channel must comply with
         the field characteristics.
         """
         success: bool = True
