@@ -58,7 +58,7 @@ class ChromaticDisp(AbstractParameter):
     def __call__(self, omega: np.ndarray, order: int) -> np.ndarray: ...
     # ------------------------------------------------------------------
     def __call__(self, omega, order=0):
-        """Compute the derivatives of the chromatic dispersion
+        r"""Compute the derivatives of the chromatic dispersion
         propagation constant.
 
         Parameters
@@ -391,4 +391,4 @@ if __name__ == "__main__":
     plot_titles.append('Dispersion slope of Silica')
 
     oc.plot2d(x_data, y_data, x_labels=x_labels, y_labels=y_labels,
-              plot_titles=plot_titles, split=True, opacity=[0.0])
+              plot_titles=plot_titles, split=True, line_opacities=[0.0])
