@@ -54,7 +54,7 @@ class AsymmetryCoeff(AbstractParameter):
     def __call__(self, omega: np.ndarray) -> np.ndarray: ...
     # ------------------------------------------------------------------
     def __call__(self, omega):
-        """Compute the asymmetry coefficient.
+        r"""Compute the asymmetry coefficient.
 
         Parameters
         ----------
@@ -164,5 +164,5 @@ if __name__ == "__main__":
                                       cst.CLAD_DOPANT_CONCENT)]
 
     oc.plot2d([lambdas], [res], x_labels=x_labels, y_labels=y_labels,
-              plot_titles=plot_titles, opacity=[0.0],
+              plot_titles=plot_titles, line_opacities=[0.0],
               y_ranges=[(20e6, 45e6)])
