@@ -72,7 +72,7 @@ class DopedFiberGain(AbstractParameter):
     def __call__(self, omega: np.ndarray, order: int) -> np.ndarray: ...
     # ------------------------------------------------------------------
     def __call__(self, *args):
-        """Compute the gain coefficient.
+        r"""Compute the gain coefficient.
 
         Parameters
         ----------
@@ -114,7 +114,7 @@ class DopedFiberGain(AbstractParameter):
     # ------------------------------------------------------------------
     @staticmethod
     def calc_doped_fiber_gain(sigma, overlap, N):
-        r"""Calculate the energy saturation.
+        r"""Calculate the gain of the doped fiber.
 
         Parameters
         ----------
@@ -191,5 +191,5 @@ if __name__ == "__main__":
                               r"ratio $\frac{N_1}{N_0} = \frac{11}{10}$."]
 
     oc.plot2d([lambdas], [gains], x_labels=['Lambda'],
-              y_labels=[r'Gain, $\, g\,(km^{-1})$'], plot_colors=['red'],
-              plot_titles=plot_titles, opacity=[0.])
+              y_labels=[r'Gain, $\, g\,(km^{-1})$'], line_colors=['red'],
+              plot_titles=plot_titles, line_opacities=[0.])
